DATA_DIR = "/usr/share"
LIB_DIR = "/usr/lib"
VERSION = "2.31.2"
PACKAGE = "hamster-applet"
PYTHONDIR = "/usr/lib/python2.6/site-packages"
